@@ -24,7 +24,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: BLINflag.h,v 1.55 2021/07/26 14:00:41 cuhegh Exp $
+ * $Id: BLINflag.h,v 1.62 2021/12/18 23:56:16 babolo Exp $
  */
 
 #ifndef  _BABOLO_BLINflag_H_
@@ -46,13 +46,313 @@ __BEGIN_DECLS
 #  warning BLIN_COMPAT not defined
 # endif
 
+# define ifBLIN_FLAG  BLIN_flag blin_internal_flags
+# define BLIN_flags   blin_internal_flags
+# define BLIN_DOCRY   0x010000
+# define BLIN_DOTRACE (((blin_pamparam *)&blin_direct_flags)->tracfile >= 0)
+
+# if defined(BLIN_COMPAT2) || (defined(BLIN_COMPAT) && (BLIN_COMPAT <= 2))
+/*****************************************************************************************************/
+                                     /*   old style poins of debugging. have to be deleted sometimes */
+#  define ifBLIN_QV1(FL) if ((FL) & BLIN_BIT0)
+#  define ifBLIN_QV2(FL) if ((FL) & BLIN_BIT1)
+#  define ifBLIN_QV3(FL) if ((FL) & BLIN_BIT2)
+#  define ifBLIN_QV4(FL) if ((FL) & BLIN_BIT3)
+#  define ifBLIN_QV5(FL) if ((FL) & BLIN_BIT4)
+#  define ifBLIN_QV6(FL) if ((FL) & BLIN_BIT5)
+#  define ifBLIN_QV7(FL) if ((FL) & BLIN_BIT6)
+#  define ifBLIN_QV8(FL) if ((FL) & BLIN_BIT7)
+
+# endif /* BLIN_COMPAT2 */
+
+/*****************************************************************************************************/
+                                     /*                                 new style poins of debugging */
+
+/*****************************************************************************************************/
+                                                      /* XXXX */
+# if defined(BLIN_COMPAT) && (BLIN_COMPAT <= 3)
+#  define BLIN_DU_TEXT BLIN_MODDTXT                                      /* text right on bytes      */
+
+#  define ifBLIN_TEMPLATE(L, F, ...)                                                                  \
+     blin_cry1((L), "%s:%s:%d: " F, __FILE__, __func__, __LINE__, ## __VA_ARGS__)
+
+#  define ifBLIN_TPL(L, F, ...)                                                                       \
+     blin_cry1((L), "%s:%s:%d: " F, __FILE__, __func__, __LINE__, ## __VA_ARGS__)
+
+#  define ifBLIN_NOW(L, F, ...)                                                                       \
+     blin_cry1((L), "%s:%s:%d: " F, __FILE__, __func__, __LINE__, ## __VA_ARGS__)
+
+#  define ifBLIN_QQ0(FL) if ((FL) & BLIN_BIT0)
+#  define ifBLIN_QQ1(FL) if ((FL) & BLIN_BIT1)
+#  define ifBLIN_QQ2(FL) if ((FL) & BLIN_BIT2)
+#  define ifBLIN_QQ3(FL) if ((FL) & BLIN_BIT3)
+#  define ifBLIN_QQ4(FL) if ((FL) & BLIN_BIT4)
+#  define ifBLIN_QQ5(FL) if ((FL) & BLIN_BIT5)
+#  define ifBLIN_QQ6(FL) if ((FL) & BLIN_BIT6)
+#  define ifBLIN_QQ7(FL) if ((FL) & BLIN_BIT7)
+
+#  define ifBLIN_QO0 if ((blin_internal_flags) & BLIN_BIT0)
+#  define ifBLIN_QO1 if ((blin_internal_flags) & BLIN_BIT1)
+#  define ifBLIN_QO2 if ((blin_internal_flags) & BLIN_BIT2)
+#  define ifBLIN_QO3 if ((blin_internal_flags) & BLIN_BIT3)
+#  define ifBLIN_QO4 if ((blin_internal_flags) & BLIN_BIT4)
+#  define ifBLIN_QO5 if ((blin_internal_flags) & BLIN_BIT5)
+#  define ifBLIN_QO6 if ((blin_internal_flags) & BLIN_BIT6)
+#  define ifBLIN_QO7 if ((blin_internal_flags) & BLIN_BIT7)
+
+#  define ifBLIN_QU0(FL, F, ...) ifBLIN_QQ0(FL) ifBLIN_TPL(0, F, ## __VA_ARGS__)
+#  define ifBLIN_QU1(FL, F, ...) ifBLIN_QQ1(FL) ifBLIN_TPL(1, F, ## __VA_ARGS__)
+#  define ifBLIN_QU2(FL, F, ...) ifBLIN_QQ2(FL) ifBLIN_TPL(2, F, ## __VA_ARGS__)
+#  define ifBLIN_QU3(FL, F, ...) ifBLIN_QQ3(FL) ifBLIN_TPL(3, F, ## __VA_ARGS__)
+#  define ifBLIN_QU4(FL, F, ...) ifBLIN_QQ4(FL) ifBLIN_TPL(4, F, ## __VA_ARGS__)
+#  define ifBLIN_QU5(FL, F, ...) ifBLIN_QQ5(FL) ifBLIN_TPL(5, F, ## __VA_ARGS__)
+#  define ifBLIN_QU6(FL, F, ...) ifBLIN_QQ6(FL) ifBLIN_TPL(6, F, ## __VA_ARGS__)
+#  define ifBLIN_QU7(FL, F, ...) ifBLIN_QQ7(FL) ifBLIN_TPL(7, F, ## __VA_ARGS__)
+
+#  define ifBLIN_QX0(F, ...) ifBLIN_QO0 ifBLIN_TPL( 0, F, ## __VA_ARGS__)
+#  define ifBLIN_QX1(F, ...) ifBLIN_QO1 ifBLIN_TPL( 1, F, ## __VA_ARGS__)
+#  define ifBLIN_QX2(F, ...) ifBLIN_QO2 ifBLIN_TPL( 2, F, ## __VA_ARGS__)
+#  define ifBLIN_QX3(F, ...) ifBLIN_QO3 ifBLIN_TPL( 3, F, ## __VA_ARGS__)
+#  define ifBLIN_QX4(F, ...) ifBLIN_QO4 ifBLIN_TPL( 4, F, ## __VA_ARGS__)
+#  define ifBLIN_QX5(F, ...) ifBLIN_QO5 ifBLIN_TPL( 5, F, ## __VA_ARGS__)
+#  define ifBLIN_QX6(F, ...) ifBLIN_QO6 ifBLIN_TPL( 6, F, ## __VA_ARGS__)
+#  define ifBLIN_QX7(F, ...) ifBLIN_QO7 ifBLIN_TPL( 7, F, ## __VA_ARGS__)
+
+#  define ifBLIN_QW0(F, ...) ifBLIN_QO0 ifBLIN_TPL( 8, F, ## __VA_ARGS__)
+#  define ifBLIN_QW1(F, ...) ifBLIN_QO1 ifBLIN_TPL( 9, F, ## __VA_ARGS__)
+#  define ifBLIN_QW2(F, ...) ifBLIN_QO2 ifBLIN_TPL(10, F, ## __VA_ARGS__)
+#  define ifBLIN_QW3(F, ...) ifBLIN_QO3 ifBLIN_TPL(11, F, ## __VA_ARGS__)
+#  define ifBLIN_QW4(F, ...) ifBLIN_QO4 ifBLIN_TPL(12, F, ## __VA_ARGS__)
+#  define ifBLIN_QW5(F, ...) ifBLIN_QO5 ifBLIN_TPL(13, F, ## __VA_ARGS__)
+#  define ifBLIN_QW6(F, ...) ifBLIN_QO6 ifBLIN_TPL(14, F, ## __VA_ARGS__)
+#  define ifBLIN_QW7(F, ...) ifBLIN_QO7 ifBLIN_TPL(15, F, ## __VA_ARGS__)
+
+#  define ifBLIN_QZ0(F, ...) ifBLIN_NOW( 0, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ1(F, ...) ifBLIN_NOW( 1, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ2(F, ...) ifBLIN_NOW( 2, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ3(F, ...) ifBLIN_NOW( 3, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ4(F, ...) ifBLIN_NOW( 4, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ5(F, ...) ifBLIN_NOW( 5, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ6(F, ...) ifBLIN_NOW( 6, F, ## __VA_ARGS__)
+#  define ifBLIN_QZ7(F, ...) ifBLIN_NOW( 7, F, ## __VA_ARGS__)
+
+#  define ifBLIN_QY0(F, ...) ifBLIN_NOW( 8, F, ## __VA_ARGS__)
+#  define ifBLIN_QY1(F, ...) ifBLIN_NOW( 9, F, ## __VA_ARGS__)
+#  define ifBLIN_QY2(F, ...) ifBLIN_NOW(10, F, ## __VA_ARGS__)
+#  define ifBLIN_QY3(F, ...) ifBLIN_NOW(11, F, ## __VA_ARGS__)
+#  define ifBLIN_QY4(F, ...) ifBLIN_NOW(12, F, ## __VA_ARGS__)
+#  define ifBLIN_QY5(F, ...) ifBLIN_NOW(13, F, ## __VA_ARGS__)
+#  define ifBLIN_QY6(F, ...) ifBLIN_NOW(14, F, ## __VA_ARGS__)
+#  define ifBLIN_QY7(F, ...) ifBLIN_NOW(15, F, ## __VA_ARGS__)
+
+# else
+
+#  define ifBLIN_TEMPLATE(FL, L, F, ...)                                                              \
+     blin_cry4((L) | ((FL) ? BLIN_DOCRY : 0), __FILE__, __func__, __LINE__, F, ## __VA_ARGS__)
+
+#  define ifBLIN_TPL(FL, L, F, ...)                                                                   \
+     blin_cry4((L) | ((FL) ? BLIN_DOCRY : 0), __FILE__, __func__, __LINE__, F, ## __VA_ARGS__)
+
+#  define ifBLIN_NOW(L, F, ...)                                                                       \
+     blin_cry4((L) | BLIN_DOCRY, __FILE__, __func__, __LINE__, F, ## __VA_ARGS__)
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 0)
+
+#   define ifBLIN_QN0(BLIN) BLIN
+#   define ifBLIN_QQ0(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT0))
+#   define ifBLIN_QO0       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT0))
+#   define ifBLIN_QU0(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT0, 0, F, ## __VA_ARGS__)
+#   define ifBLIN_QX0(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT0,  0, F, ## __VA_ARGS__)
+#   define ifBLIN_QW0(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT0,  8, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ0(    F, ...) ifBLIN_NOW( 0, F, ## __VA_ARGS__)
+#   define ifBLIN_QY0(    F, ...) ifBLIN_NOW( 8, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN0(BLIN)
+#   define ifBLIN_QQ0(FL)   if (0)
+#   define ifBLIN_QO0       if (0)
+#   define ifBLIN_QU0(FL, F, ...)
+#   define ifBLIN_QX0(    F, ...)
+#   define ifBLIN_QW0(    F, ...)
+#   define ifBLIN_QZ0(    F, ...)
+#   define ifBLIN_QY0(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 1)
+
+#   define ifBLIN_QN1(BLIN) BLIN
+#   define ifBLIN_QQ1(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT1))
+#   define ifBLIN_QO1       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT1))
+#   define ifBLIN_QU1(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT1, 1, F, ## __VA_ARGS__)
+#   define ifBLIN_QX1(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT1,  1, F, ## __VA_ARGS__)
+#   define ifBLIN_QW1(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT1,  9, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ1(    F, ...) ifBLIN_NOW( 1, F, ## __VA_ARGS__)
+#   define ifBLIN_QY1(    F, ...) ifBLIN_NOW( 9, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN1(BLIN)
+#   define ifBLIN_QQ1(FL)   if (0)
+#   define ifBLIN_QO1       if (0)
+#   define ifBLIN_QU1(FL, F, ...)
+#   define ifBLIN_QX1(    F, ...)
+#   define ifBLIN_QW1(    F, ...)
+#   define ifBLIN_QZ1(    F, ...)
+#   define ifBLIN_QY1(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 2)
+
+#   define ifBLIN_QN2(BLIN) BLIN
+#   define ifBLIN_QQ2(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT2))
+#   define ifBLIN_QO2       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT2))
+#   define ifBLIN_QU2(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT2, 2, F, ## __VA_ARGS__)
+#   define ifBLIN_QX2(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT2,  2, F, ## __VA_ARGS__)
+#   define ifBLIN_QW2(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT2, 10, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ2(    F, ...) ifBLIN_NOW( 2, F, ## __VA_ARGS__)
+#   define ifBLIN_QY2(    F, ...) ifBLIN_NOW(10, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN2(BLIN)
+#   define ifBLIN_QQ2(FL)   if (0)
+#   define ifBLIN_QO2       if (0)
+#   define ifBLIN_QU2(FL, F, ...)
+#   define ifBLIN_QX2(    F, ...)
+#   define ifBLIN_QW2(    F, ...)
+#   define ifBLIN_QZ2(    F, ...)
+#   define ifBLIN_QY2(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 3)
+
+#   define ifBLIN_QN3(BLIN) BLIN
+#   define ifBLIN_QQ3(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT3))
+#   define ifBLIN_QO3       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT3))
+#   define ifBLIN_QU3(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT3, 3, F, ## __VA_ARGS__)
+#   define ifBLIN_QX3(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT3,  3, F, ## __VA_ARGS__)
+#   define ifBLIN_QW3(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT3, 11, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ3(    F, ...) ifBLIN_NOW( 3, F, ## __VA_ARGS__)
+#   define ifBLIN_QY3(    F, ...) ifBLIN_NOW(11, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN3(BLIN)
+#   define ifBLIN_QQ3(FL)   if (0)
+#   define ifBLIN_QO3       if (0)
+#   define ifBLIN_QU3(FL, F, ...)
+#   define ifBLIN_QX3(    F, ...)
+#   define ifBLIN_QW3(    F, ...)
+#   define ifBLIN_QZ3(    F, ...)
+#   define ifBLIN_QY3(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 4)
+
+#   define ifBLIN_QN4(BLIN) BLIN
+#   define ifBLIN_QQ4(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT4))
+#   define ifBLIN_QO4       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT4))
+#   define ifBLIN_QU4(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT4, 4, F, ## __VA_ARGS__)
+#   define ifBLIN_QX4(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT4,  4, F, ## __VA_ARGS__)
+#   define ifBLIN_QW4(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT4, 12, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ4(    F, ...) ifBLIN_NOW( 4, F, ## __VA_ARGS__)
+#   define ifBLIN_QY4(    F, ...) ifBLIN_NOW(12, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN4(BLIN)
+#   define ifBLIN_QQ4(FL)   if (0)
+#   define ifBLIN_QO4       if (0)
+#   define ifBLIN_QU4(FL, F, ...)
+#   define ifBLIN_QX4(    F, ...)
+#   define ifBLIN_QW4(    F, ...)
+#   define ifBLIN_QZ4(    F, ...)
+#   define ifBLIN_QY4(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 5)
+
+#   define ifBLIN_QN5(BLIN) BLIN
+#   define ifBLIN_QQ5(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT5))
+#   define ifBLIN_QO5       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT5))
+#   define ifBLIN_QU5(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT5, 5, F, ## __VA_ARGS__)
+#   define ifBLIN_QX5(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT5,  5, F, ## __VA_ARGS__)
+#   define ifBLIN_QW5(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT5, 13, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ5(    F, ...) ifBLIN_NOW( 5, F, ## __VA_ARGS__)
+#   define ifBLIN_QY5(    F, ...) ifBLIN_NOW(13, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN5(BLIN)
+#   define ifBLIN_QQ5(FL)   if (0)
+#   define ifBLIN_QO5       if (0)
+#   define ifBLIN_QU5(FL, F, ...)
+#   define ifBLIN_QX5(    F, ...)
+#   define ifBLIN_QW5(    F, ...)
+#   define ifBLIN_QZ5(    F, ...)
+#   define ifBLIN_QY5(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 6)
+
+#   define ifBLIN_QN6(BLIN) BLIN
+#   define ifBLIN_QQ6(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT6))
+#   define ifBLIN_QO6       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT6))
+#   define ifBLIN_QU6(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT6, 6, F, ## __VA_ARGS__)
+#   define ifBLIN_QX6(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT6,  6, F, ## __VA_ARGS__)
+#   define ifBLIN_QW6(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT6, 14, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ6(    F, ...) ifBLIN_NOW( 6, F, ## __VA_ARGS__)
+#   define ifBLIN_QY6(    F, ...) ifBLIN_NOW(14, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN6(BLIN)
+#   define ifBLIN_QQ6(FL)   if (0)
+#   define ifBLIN_QO6       if (0)
+#   define ifBLIN_QU6(FL, F, ...)
+#   define ifBLIN_QX6(    F, ...)
+#   define ifBLIN_QW6(    F, ...)
+#   define ifBLIN_QZ6(    F, ...)
+#   define ifBLIN_QY6(    F, ...)
+
+#  endif
+
+#  if !defined(BLIN_NON) || (BLIN_NON > 7)
+
+#   define ifBLIN_QN7(BLIN) BLIN
+#   define ifBLIN_QQ7(FL)   if (BLIN_DOTRACE || ((FL) & BLIN_BIT7))
+#   define ifBLIN_QO7       if (BLIN_DOTRACE || ((blin_internal_flags) & BLIN_BIT7))
+#   define ifBLIN_QU7(FL, F, ...) ifBLIN_TPL((FL) & BLIN_BIT7, 7, F, ## __VA_ARGS__)
+#   define ifBLIN_QX7(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT7,  7, F, ## __VA_ARGS__)
+#   define ifBLIN_QW7(    F, ...) ifBLIN_TPL((blin_internal_flags) & BLIN_BIT7, 15, F, ## __VA_ARGS__)
+#   define ifBLIN_QZ7(    F, ...) ifBLIN_NOW( 7, F, ## __VA_ARGS__)
+#   define ifBLIN_QY7(    F, ...) ifBLIN_NOW(15, F, ## __VA_ARGS__)
+
+#  else
+
+#   define ifBLIN_QN7(BLIN)
+#   define ifBLIN_QQ7(FL)   if (0)
+#   define ifBLIN_QO7       if (0)
+#   define ifBLIN_QU7(FL, F, ...)
+#   define ifBLIN_QX7(    F, ...)
+#   define ifBLIN_QW7(    F, ...)
+#   define ifBLIN_QZ7(    F, ...)
+#   define ifBLIN_QY7(    F, ...)
+
+#  endif
+# endif
+
 typedef u_int32_t BLIN_flag;
 
 /*****************************************************************************************************/
 /*                                                                               BLIN infrastructure */
-# define ifBLIN_FLAG BLIN_flag blin_internal_flags
-# define BLIN_flags blin_internal_flags
-
 typedef struct blin_pamparam {
     BLIN_flag flags;                 /*                   0    */
 /*                                                                    for use in points of debugging */
@@ -84,7 +384,7 @@ typedef struct blin_pamparam {
 #  define BLIN_VER6    BLIN_BIT5
 #  define BLIN_VER7    BLIN_BIT6
 #  define BLIN_VER8    BLIN_BIT7
-#  define BLIN_VERMASK 0xFF000000
+#  define BLIN_VERMASK BLIN_MASK
 # endif /* BLIN_COMPAT2 */
     int           err;
     struct {
@@ -112,190 +412,6 @@ typedef struct blin_pamparam {
     void         *dummy3;
 } blin_pamparam;
 
-# if defined(BLIN_COMPAT2) || (defined(BLIN_COMPAT) && (BLIN_COMPAT <= 2))
-/*****************************************************************************************************/
-                                     /*   old style poins of debugging. have to be deleted sometimes */
-#  ifdef(BLIN_NON)
-#   define ifBLIN_QV1(flags) if (0)
-#   define ifBLIN_QV2(flags) if (0)
-#   define ifBLIN_QV3(flags) if (0)
-#   define ifBLIN_QV4(flags) if (0)
-#   define ifBLIN_QV5(flags) if (0)
-#   define ifBLIN_QV6(flags) if (0)
-#   define ifBLIN_QV7(flags) if (0)
-#   define ifBLIN_QV8(flags) if (0)
-#  else
-#   define ifBLIN_QV1(flags) if ((flags) & BLIN_BIT0)
-#   define ifBLIN_QV2(flags) if ((flags) & BLIN_BIT1)
-#   define ifBLIN_QV3(flags) if ((flags) & BLIN_BIT2)
-#   define ifBLIN_QV4(flags) if ((flags) & BLIN_BIT3)
-#   define ifBLIN_QV5(flags) if ((flags) & BLIN_BIT4)
-#   define ifBLIN_QV6(flags) if ((flags) & BLIN_BIT5)
-#   define ifBLIN_QV7(flags) if ((flags) & BLIN_BIT6)
-#   define ifBLIN_QV8(flags) if ((flags) & BLIN_BIT7)
-#  endif
-
-# endif /* BLIN_COMPAT2 */
-
-/*****************************************************************************************************/
-                                     /*                                 new style poins of debugging */
-# ifdef BLIN_NON
-#  define ifBLIN_QQ0(FLAGS) if (0)
-#  define ifBLIN_QQ1(FLAGS) if (0)
-#  define ifBLIN_QQ2(FLAGS) if (0)
-#  define ifBLIN_QQ3(FLAGS) if (0)
-#  define ifBLIN_QQ4(FLAGS) if (0)
-#  define ifBLIN_QQ5(FLAGS) if (0)
-#  define ifBLIN_QQ6(FLAGS) if (0)
-#  define ifBLIN_QQ7(FLAGS) if (0)
-#  define ifBLIN_QO0 if (0)
-#  define ifBLIN_QO1 if (0)
-#  define ifBLIN_QO2 if (0)
-#  define ifBLIN_QO3 if (0)
-#  define ifBLIN_QO4 if (0)
-#  define ifBLIN_QO5 if (0)
-#  define ifBLIN_QO6 if (0)
-#  define ifBLIN_QO7 if (0)
-# else
-#  define ifBLIN_QQ0(FLAGS) if ((FLAGS) & BLIN_BIT0)
-#  define ifBLIN_QQ1(FLAGS) if ((FLAGS) & BLIN_BIT1)
-#  define ifBLIN_QQ2(FLAGS) if ((FLAGS) & BLIN_BIT2)
-#  define ifBLIN_QQ3(FLAGS) if ((FLAGS) & BLIN_BIT3)
-#  define ifBLIN_QQ4(FLAGS) if ((FLAGS) & BLIN_BIT4)
-#  define ifBLIN_QQ5(FLAGS) if ((FLAGS) & BLIN_BIT5)
-#  define ifBLIN_QQ6(FLAGS) if ((FLAGS) & BLIN_BIT6)
-#  define ifBLIN_QQ7(FLAGS) if ((FLAGS) & BLIN_BIT7)
-#  define ifBLIN_QO0 if ((blin_internal_flags) & BLIN_BIT0)
-#  define ifBLIN_QO1 if ((blin_internal_flags) & BLIN_BIT1)
-#  define ifBLIN_QO2 if ((blin_internal_flags) & BLIN_BIT2)
-#  define ifBLIN_QO3 if ((blin_internal_flags) & BLIN_BIT3)
-#  define ifBLIN_QO4 if ((blin_internal_flags) & BLIN_BIT4)
-#  define ifBLIN_QO5 if ((blin_internal_flags) & BLIN_BIT5)
-#  define ifBLIN_QO6 if ((blin_internal_flags) & BLIN_BIT6)
-#  define ifBLIN_QO7 if ((blin_internal_flags) & BLIN_BIT7)
-# endif
-
-# if defined(BLIN_COMPAT) && (BLIN_COMPAT <= 3)
-
-#  define ifBLIN_QU0(FLAGS, F, ...) ifBLIN_QQ0(FLAGS) ifBLIN_TEMPLATE(0, F, ## __VA_ARGS__)
-#  define ifBLIN_QU1(FLAGS, F, ...) ifBLIN_QQ1(FLAGS) ifBLIN_TEMPLATE(1, F, ## __VA_ARGS__)
-#  define ifBLIN_QU2(FLAGS, F, ...) ifBLIN_QQ2(FLAGS) ifBLIN_TEMPLATE(2, F, ## __VA_ARGS__)
-#  define ifBLIN_QU3(FLAGS, F, ...) ifBLIN_QQ3(FLAGS) ifBLIN_TEMPLATE(3, F, ## __VA_ARGS__)
-#  define ifBLIN_QU4(FLAGS, F, ...) ifBLIN_QQ4(FLAGS) ifBLIN_TEMPLATE(4, F, ## __VA_ARGS__)
-#  define ifBLIN_QU5(FLAGS, F, ...) ifBLIN_QQ5(FLAGS) ifBLIN_TEMPLATE(5, F, ## __VA_ARGS__)
-#  define ifBLIN_QU6(FLAGS, F, ...) ifBLIN_QQ6(FLAGS) ifBLIN_TEMPLATE(6, F, ## __VA_ARGS__)
-#  define ifBLIN_QU7(FLAGS, F, ...) ifBLIN_QQ7(FLAGS) ifBLIN_TEMPLATE(7, F, ## __VA_ARGS__)
-#  define ifBLIN_QX0(F, ...) ifBLIN_QO0 ifBLIN_TEMPLATE( 0, F, ## __VA_ARGS__)
-#  define ifBLIN_QX1(F, ...) ifBLIN_QO1 ifBLIN_TEMPLATE( 1, F, ## __VA_ARGS__)
-#  define ifBLIN_QX2(F, ...) ifBLIN_QO2 ifBLIN_TEMPLATE( 2, F, ## __VA_ARGS__)
-#  define ifBLIN_QX3(F, ...) ifBLIN_QO3 ifBLIN_TEMPLATE( 3, F, ## __VA_ARGS__)
-#  define ifBLIN_QX4(F, ...) ifBLIN_QO4 ifBLIN_TEMPLATE( 4, F, ## __VA_ARGS__)
-#  define ifBLIN_QX5(F, ...) ifBLIN_QO5 ifBLIN_TEMPLATE( 5, F, ## __VA_ARGS__)
-#  define ifBLIN_QX6(F, ...) ifBLIN_QO6 ifBLIN_TEMPLATE( 6, F, ## __VA_ARGS__)
-#  define ifBLIN_QX7(F, ...) ifBLIN_QO7 ifBLIN_TEMPLATE( 7, F, ## __VA_ARGS__)
-#  define ifBLIN_QW0(F, ...) ifBLIN_QO0 ifBLIN_TEMPLATE( 8, F, ## __VA_ARGS__)
-#  define ifBLIN_QW1(F, ...) ifBLIN_QO1 ifBLIN_TEMPLATE( 9, F, ## __VA_ARGS__)
-#  define ifBLIN_QW2(F, ...) ifBLIN_QO2 ifBLIN_TEMPLATE(10, F, ## __VA_ARGS__)
-#  define ifBLIN_QW3(F, ...) ifBLIN_QO3 ifBLIN_TEMPLATE(11, F, ## __VA_ARGS__)
-#  define ifBLIN_QW4(F, ...) ifBLIN_QO4 ifBLIN_TEMPLATE(12, F, ## __VA_ARGS__)
-#  define ifBLIN_QW5(F, ...) ifBLIN_QO5 ifBLIN_TEMPLATE(13, F, ## __VA_ARGS__)
-#  define ifBLIN_QW6(F, ...) ifBLIN_QO6 ifBLIN_TEMPLATE(14, F, ## __VA_ARGS__)
-#  define ifBLIN_QW7(F, ...) ifBLIN_QO7 ifBLIN_TEMPLATE(15, F, ## __VA_ARGS__)
-
-#  define ifBLIN_TEMPLATE(LEVEL, FORMAT, ...)                                                         \
-     do {blin_cry1((LEVEL), "%s:%s:%d: " FORMAT, __FILE__, __func__, __LINE__, ## __VA_ARGS__);       \
-     } while (0)                                                                                   
-
-# else
-
-#  define ifBLIN_QU0(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT0, 0, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU1(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT1, 1, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU2(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT2, 2, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU3(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT3, 3, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU4(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT4, 4, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU5(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT5, 5, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU6(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT6, 6, (F), ## __VA_ARGS__)
-#  define ifBLIN_QU7(FLAGS, F, ...) ifBLIN_TEMPLATE((FLAGS) & BLIN_BIT7, 7, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX0(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT0, 0, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX1(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT1, 1, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX2(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT2, 2, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX3(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT3, 3, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX4(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT4, 4, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX5(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT5, 5, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX6(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT6, 6, (F), ## __VA_ARGS__)
-#  define ifBLIN_QX7(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT7, 7, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW0(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT0, 8, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW1(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT1, 9, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW2(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT2, 10, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW3(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT3, 11, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW4(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT4, 12, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW5(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT5, 13, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW6(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT6, 14, (F), ## __VA_ARGS__)
-#  define ifBLIN_QW7(F, ...) ifBLIN_TEMPLATE((blin_internal_flags) & BLIN_BIT7, 15, (F), ## __VA_ARGS__)
-
-#  define ifBLIN_TEMPLATE(FLAGS, LEVEL, FORMAT, ...)                                                  \
-     do {blin_cry4( (LEVEL) | ((FLAGS) ? BLIN_DOCRY : 0), __FILE__, __func__, __LINE__                \
-                  , (FORMAT), ## __VA_ARGS__);                                                        \
-     } while (0)
-# endif
-
-# ifdef BLIN_NON
-#  undef ifBLIN_TEMPLATE
-#  define ifBLIN_TEMPLATE(FLAGS, LEVEL, FORMAT, ...)
-# endif
-
-# if defined(BLIN_COMPAT) && (BLIN_COMPAT <= 3)
-
-#  define ifBLIN_QZ0(F, ...) ifBLIN_NOW( 0, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ1(F, ...) ifBLIN_NOW( 1, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ2(F, ...) ifBLIN_NOW( 2, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ3(F, ...) ifBLIN_NOW( 3, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ4(F, ...) ifBLIN_NOW( 4, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ5(F, ...) ifBLIN_NOW( 5, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ6(F, ...) ifBLIN_NOW( 6, F, ## __VA_ARGS__)
-#  define ifBLIN_QZ7(F, ...) ifBLIN_NOW( 7, F, ## __VA_ARGS__)
-#  define ifBLIN_QY0(F, ...) ifBLIN_NOW( 8, F, ## __VA_ARGS__)
-#  define ifBLIN_QY1(F, ...) ifBLIN_NOW( 9, F, ## __VA_ARGS__)
-#  define ifBLIN_QY2(F, ...) ifBLIN_NOW(10, F, ## __VA_ARGS__)
-#  define ifBLIN_QY3(F, ...) ifBLIN_NOW(11, F, ## __VA_ARGS__)
-#  define ifBLIN_QY4(F, ...) ifBLIN_NOW(12, F, ## __VA_ARGS__)
-#  define ifBLIN_QY5(F, ...) ifBLIN_NOW(13, F, ## __VA_ARGS__)
-#  define ifBLIN_QY6(F, ...) ifBLIN_NOW(14, F, ## __VA_ARGS__)
-#  define ifBLIN_QY7(F, ...) ifBLIN_NOW(15, F, ## __VA_ARGS__)
-
-#  define ifBLIN_NOW(LEVEL, FORMAT, ...)                                                              \
-     do {blin_cry1((LEVEL), "%s:%s:%d: " FORMAT, __FILE__, __func__, __LINE__, ## __VA_ARGS__);       \
-     } while (0)
-
-# else
-
-#  define ifBLIN_QZ0(F, ...) ifBLIN_NOW( 0, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ1(F, ...) ifBLIN_NOW( 1, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ2(F, ...) ifBLIN_NOW( 2, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ3(F, ...) ifBLIN_NOW( 3, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ4(F, ...) ifBLIN_NOW( 4, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ5(F, ...) ifBLIN_NOW( 5, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ6(F, ...) ifBLIN_NOW( 6, (F), ## __VA_ARGS__)
-#  define ifBLIN_QZ7(F, ...) ifBLIN_NOW( 7, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY0(F, ...) ifBLIN_NOW( 8, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY1(F, ...) ifBLIN_NOW( 9, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY2(F, ...) ifBLIN_NOW(10, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY3(F, ...) ifBLIN_NOW(11, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY4(F, ...) ifBLIN_NOW(12, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY5(F, ...) ifBLIN_NOW(13, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY6(F, ...) ifBLIN_NOW(14, (F), ## __VA_ARGS__)
-#  define ifBLIN_QY7(F, ...) ifBLIN_NOW(15, (F), ## __VA_ARGS__)
-
-#  define ifBLIN_NOW(LEVEL, FORMAT, ...)                                                              \
-     do {blin_cry4((LEVEL) | BLIN_DOCRY, __FILE__, __func__, __LINE__, (FORMAT), ## __VA_ARGS__);     \
-     } while (0)
-# endif
-
-# ifdef BLIN_NON
-#  undef ifBLIN_NOW
-#  define ifBLIN_NOW(LEVEL, FORMAT, ...)
-# endif
-
 /*****************************************************************************************************/
 /*                                                                                   BLIN procedures */
 extern BLIN_flag blin_internal_flags;
@@ -312,10 +428,6 @@ int             blin_cry4 __P(( int         mode     /* mode & 0x0007 level, mod
                              ));
 int             blin_64   __P((u_int64_t flags, const char * const *nm, int x, FILE *fo));
 int             blin_dumb __P((int mode, const void *buf, ssize_t len, ...));/* hex dump, mode level */
-# if defined(BLIN_COMPAT) && (BLIN_COMPAT <= 3)
-#  define BLIN_DU_TEXT BLIN_MODDTXT                                      /* text right on bytes      */
-# endif /* BLIN_COMPAT3 */
-# define BLIN_DOCRY 0x010000
 
 /*****************************************************************************************************/
                                      /*                         for blin_ctl() control 1st parameter */
@@ -412,24 +524,26 @@ int             blin_dumb __P((int mode, const void *buf, ssize_t len, ...));/*
 # if defined(BLIN_COMPAT2) || (defined(BLIN_COMPAT) && (BLIN_COMPAT <= 2))
 /*****************************************************************************************************/
 /*                                                                old style to manipulate BLIN flags */
-#  define kukBLIN_VERMASK(x)        (((BLIN_flag)(x) << 24) & BLIN_MASK)
-#  define setBLIN_VERMASK(flags, x) do{(flags) &= ~BLIN_MASK; (flags) |= kukBLIN_VERMASK(x);} while (0)
-#  define getBLIN_VERMASK(flags)    (((flags) >> 24) & (BLIN_MASK >> 24))
+#  define kukBLIN_VERMASK(x)     (((BLIN_flag)(x) << 24) & BLIN_MASK)
+#  define setBLIN_VERMASK(FL, x) do{(FL) &= ~BLIN_MASK; (FL) |= kukBLIN_VERMASK(x);} while (0)
+#  define getBLIN_VERMASK(FL)    (((FL) >> 24) & (BLIN_MASK >> 24))
 # endif /* BLIN_COMPAT2 */
 
 /*****************************************************************************************************/
 /*                                                                          to manipulate BLIN flags */
-# define BLIN_VERBOSE(flags)                                                                          \
-    do{ u_int32_t *temp = &(flags); *temp |= (BLIN_flag)BLIN_I(blin_ctl( BLIN_CTL_FLAG                \
-                                                                       | BLIN_CTL_RISE                \
-                                                                       | BLIN_CTL_NPRE                \
-                                                                       | BLIN_CTL_RMSK                \
-                                                                       | BLIN_CTL_FEQU                \
-                                                                       , *temp                        \
-                                                              )        );                             \
-    } while (0)
-# define BLIN_QUIET(flags)                                                                            \
-    do{ (flags) &= ~BLIN_MASK; blin_ctl(BLIN_CTL_FLAG | BLIN_CTL_FRST, BLIN_MASK);} while (0)
+# define BLIN_VERBOSE(FL)                                                                             \
+    do {                                                                                              \
+        u_int32_t *BLIN_temp = &(FL); *BLIN_temp |= (BLIN_flag)BLIN_I(blin_ctl( BLIN_CTL_FLAG         \
+                                                                              | BLIN_CTL_RISE         \
+                                                                              | BLIN_CTL_NPRE         \
+                                                                              | BLIN_CTL_RMSK         \
+                                                                              | BLIN_CTL_FEQU         \
+                                                                              , *BLIN_temp            \
+                                                                     )        );                      \
+    } while(0)
+
+# define BLIN_QUIET(FL)                                                                               \
+    do { (FL) &= ~BLIN_MASK; blin_ctl(BLIN_CTL_FLAG | BLIN_CTL_FRST, BLIN_MASK);} while(0)
 
 /*****************************************************************************************************/
 /*                                          for use in printf of pointers on both 32 and 64 bit arch */
@@ -580,9 +694,9 @@ typedef struct {
         u_int32_t line  : 24          /*  ,              */
                 , level : 8 ;         /*                              */
     };
-    u_int8_t snprog;                  /* -      string     */
-    u_int8_t snfile;                  /* -      string         */
-    u_int8_t snfunc;                  /* -      string     */
+    u_int8_t progsz;                  /* -      string     */
+    u_int8_t filesz;                  /* -      string         */
+    u_int8_t funcsz;                  /* -      string     */
     char string[0];                   /* _/_/_/         */
 } BLIN_trace;
 # endif
