@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2010..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2010..2022 @BABOLO http://www.babolo.ru/
  * PKG = babolo-libmake
  * All rights reserved.
  *
@@ -26,10 +26,10 @@
  */
 
 static const char copyright[] = "\
-@(#)Copyright (C)2010..2021 @BABOLO http://www.babolo.ru/\n\
+@(#)Copyright (C)2010..2022 @BABOLO http://www.babolo.ru/\n\
 @(#)All rights reserved.\n\
 @(#)V.M "VERS;
-static const char rcsid[] = "$Id: blin.c,v 1.54 2021/06/11 17:55:29 cuhegh Exp $";
+static const char rcsid[] = "$Id: blin.c,v 1.59 2022/08/28 15:21:28 babolo Exp $";
 
 #define BLIN_COMPAT VMAJOR
 #define BLIN_INTERNAL
@@ -177,8 +177,11 @@ int
 blin_64(u_int64_t flags, const char * const *nm, int x, FILE *fo) {                              /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    int i, k, l, ex = 0;
+    int       ex = 0;
     u_int64_t m;
+    int       i;
+    int       k;
+    int       l;
 
     if  (x > 64) x = 64;
     if  (x < -64) x = -64;
@@ -248,11 +251,11 @@ void *
 blin_ctl(u_int32_t mode, ...) {                                                                  /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    void *res = NULL;                   /*   */
+    void     *res = NULL;               /*   */
+    va_list   ap;                       /*   va_arg */
     u_int32_t m;                        /*  */
-    va_list ap;                         /*   va_arg */
-    u_int i;                            /*    */
-    int d;                              /*  */
+    u_int     i;                        /*    */
+    int       d;                        /*  */
 
     va_start(ap, mode);
     if  (blin_pamparam_internal.flags & BLIN_TRAC) {
@@ -476,7 +479,7 @@ static void
 /*****************************************************************************************************/
 doout(int level, char *text, const char *file, const char *func, int line, int er) {             /****
  *****************************************************************************************************/
-    u_int32_t ctl = blin_pamparam_internal.w[level & 7].what;
+    u_int32_t       ctl = blin_pamparam_internal.w[level & 7].what;
     struct timespec tp;                      /*      */
 
     clock_gettime(CLOCK_REALTIME, &tp);
@@ -517,16 +520,16 @@ doout(int level, char *text, const char *file, const char *func, int line, int e
         tracinf->len    = (offsetof(BLIN_trace, string) + textlen + 7) & ~((u_int32_t)07U);
         tracinf->erno   = er;
         tracinf->pid    = getpid();
-        tracinf->time   = tp.tv_sec * 1000000000 + tp.tv_nsec;
+        tracinf->time   = tp.tv_sec * 1000000000LLU + tp.tv_nsec;
         tracinf->level  = level & 7;
         tracinf->line   = line;
-        tracinf->snprog = strlen(prog);
-        tracinf->snfile = strlen(file);
-        tracinf->snfunc = strlen(func);
+        tracinf->progsz = strlen(prog);
+        tracinf->filesz = strlen(file);
+        tracinf->funcsz = strlen(func);
         textpoint = tracinf->string;
-        textpoint = stpncpy(textpoint, prog, (size_t) tracinf->snprog);
-        textpoint = stpncpy(textpoint, file, (size_t) tracinf->snfile);
-        textpoint = stpncpy(textpoint, func, (size_t) tracinf->snfunc);
+        textpoint = stpncpy(textpoint, prog, (size_t) tracinf->progsz);
+        textpoint = stpncpy(textpoint, file, (size_t) tracinf->filesz);
+        textpoint = stpncpy(textpoint, func, (size_t) tracinf->funcsz);
         textpoint = stpncpy(textpoint, text, strlen(text));
         bzero(textpoint, 7);
         flock(blin_pamparam_internal.tracfile, LOCK_EX);
@@ -538,19 +541,19 @@ doout(int level, char *text, const char *file, const char *func, int line, int e
 int
 /*****************************************************************************************************
  *****************************************************************************************************/
-blin_cry4(int ctl, const char *file, const char *proc, int nline, const char *format, ...) {     /****
+blin_cry4(int ctl, const char *file, const char *func, int nline, const char *format, ...) {     /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    char qq[BLIN_MAXCRY1 + 4];              /*                                      */
-    char *buf = NULL;                       /*                                                 */
-    char *ptr;                              /*  */
-    ssize_t avail;                          /*                              */
-    ssize_t t;                              /*  */
-    ssize_t need = 0;                       /*                                 */
     u_int32_t control;                      /* what    blin_pamparam_internal */
-    int er = errno;                         /*  errno                                      */
-    int ex = EX_OK;                         /*                                              */
-    va_list ap;                             /*   va_arg                               */
+    ssize_t   avail;                        /*                              */
+    ssize_t   need = 0;                     /*                                 */
+    char     *buf  = NULL;                  /*                                                 */
+    char     *ptr  = NULL;                  /*  */
+    char      qq   [BLIN_MAXCRY1 + 4];      /*                                      */
+    int       er   = errno;                 /*  errno                                      */
+    int       ex   = EX_OK;                 /*                                              */
+    va_list   ap;                           /*   va_arg                               */
+    ssize_t   t;                            /*  */
 
     blin_init();
     if  (blin_pamparam_internal.flags & BLIN_TRAC) {
@@ -628,7 +631,7 @@ blin_cry4(int ctl, const char *file, const char *proc, int nline, const char *fo
                 if  (er < 0) ++ptr;
         }   }
         if  (control & BLIN_MODEOAU) {
-            if  (ptr[-1] != '\n') control |= BLIN_MODEOLF;
+            if  ((ptr <= buf) || (ptr[-1] != '\n')) control |= BLIN_MODEOLF;
         }
         if  (!(~control & (BLIN_MODEOCR | BLIN_MODPRNT))) {
             *(ptr++) = '\r';
@@ -643,7 +646,7 @@ blin_cry4(int ctl, const char *file, const char *proc, int nline, const char *fo
         va_end(ap);
     } while (avail <= 0);
     *(ptr++) = '\0';
-    doout(ctl & (BLIN_DOCRY | 7), buf, file, proc, nline, er);
+    doout(ctl & (BLIN_DOCRY | 7), buf, file, func, nline, er);
 out:
     if  (buf != qq) free(buf);
     if  (blin_pamparam_internal.flags & BLIN_TRAC) {
