@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2020 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2020..2022 @BABOLO http://www.babolo.ru/
  * PKG = babolo-libmake
  * All rights reserved.
  *
@@ -23,10 +23,14 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- *
- * $Id: blin3.c,v 1.3 2020/12/01 18:42:39 nirvana Exp $
  */
 
+static const char copyright[] = "\
+@(#)Copyright (C)2020..2022 @BABOLO http://www.babolo.ru/\n\
+@(#)All rights reserved.\n\
+@(#)V.M "VERS;
+static const char rcsid[] = "$Id: blin3.c,v 1.5 2022/08/28 15:21:28 babolo Exp $";
+
 #define BLIN_COMPAT VMAJOR
 #define BLIN_INTERNAL
 
@@ -59,6 +63,8 @@ blin_init() {
  *****************************************************************************************************/
     int i;
 
+    (void)copyright;
+    (void)rcsid;
     if  (!(blin_pamparam_internal.flags & BLIN_MAININI)) {
         if  (blin_pamparam_internal.flags & BLIN_TRAC) {
             fprintf( blin_pamparam_internal.w[0].file
@@ -97,7 +103,7 @@ static void
 /*****************************************************************************************************/
 dotime(int level) {                                                                              /****
  *****************************************************************************************************/
-    u_int32_t ctl = blin_pamparam_internal.w[level].what;
+    u_int32_t       ctl = blin_pamparam_internal.w[level].what;
     struct timespec tp;                              /*      */
 
     if  (ctl & BLIN_MODTIME) {
@@ -124,17 +130,17 @@ int
 blin_cry1(int ctl, const char *format, ...) {                                                    /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    char qq[BLIN_MAXCRY1 + 4];              /*                                      */
-    char *buf;                              /*                                                 */
-    char *ptr;                              /*  */
-    ssize_t avail;                          /*                              */
-    ssize_t t;                              /*  */
-    ssize_t need = 0;                       /*                                 */
+    u_int32_t       control;                /* what    blin_pamparam_internal */
+    ssize_t         avail;                  /*                              */
+    ssize_t         need = 0;               /*                                 */
+    char           *buf;                    /*                                                 */
+    char           *ptr;                    /*  */
+    char            qq   [BLIN_MAXCRY1 + 4];/*                                      */
     struct timespec tp;                     /*               */
-    u_int32_t control;                      /* what    blin_pamparam_internal */
-    int er;                                 /*  errno                                      */
-    int ex = EX_OK;                         /*                                              */
-    va_list ap;                             /*   va_arg                               */
+    int             er;                     /*  errno                                      */
+    int             ex   = EX_OK;           /*                                              */
+    va_list         ap;                     /*   va_arg                               */
+    ssize_t         t;                      /*  */
 
     er = errno;
     blin_init();
@@ -251,15 +257,18 @@ int
 blin_stateheader(blin_statectl staflag, const char actnames[][3]) {                              /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    int i, ex = EX_OK;
-    u_int32_t ctl;
-    ssize_t l, t;
-    char *q, *p;
 #ifdef __amd64__
     const char *header = "nst rs cl st --rg32-- ----offs----";
 #else
     const char *header = "nst rs cl st --rg32-- --offs--";
 #endif
+    u_int32_t   ctl;
+    int         ex     = EX_OK;
+    char       *q;
+    char       *p;
+    int         i;
+    ssize_t     l;
+    ssize_t     t;
 
     blin_init();
     if  (blin_pamparam_internal.flags & (BLIN_BIT0 << staflag.level)) {
@@ -360,12 +369,17 @@ blin_statebody( blin_statectl  staflag         /* level gtequ staten actinn bord
               ) {                                                                                   /*
  *****************************************************************************************************/
 /*****************************************************************************************************/
+    u_int64_t contrana;
     u_int64_t C_state = BLIN_MIMASK(staflag.staten);
-    u_int64_t flymask, contrana;
-    int i, k, ex = EX_OK;
+    u_int64_t flymask;
+    int       ex      = EX_OK;
+    int       i;
+    int       k;
     u_int32_t ctl;
-    ssize_t l, t;
-    char *q, *p;
+    ssize_t   l;
+    ssize_t   t;
+    char     *q;
+    char     *p;
 
     blin_init();
     if  (blin_pamparam_internal.flags & (BLIN_BIT0 << staflag.level)) {
@@ -524,13 +538,16 @@ int
 blin_dumb(int mode, const void *buf, ssize_t len, ...) {                                         /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    char q[BLIN_MAXTXTDUM + BLIN_MAXSTRDUM + 3], *p, *s;
-    int i, ex = EX_OK;
-    u_int32_t control;
+    u_int32_t     control;
+    int           ex = EX_OK;
+    va_list       ap;
+    char          q    [BLIN_MAXTXTDUM + BLIN_MAXSTRDUM + 3];
+    char         *p;
+    char         *s;
+    int           i;
     const u_char *c;
-    va_list ap;
-    ssize_t t;
-    size_t l;
+    ssize_t       t;
+    size_t        l;
 
     if  (blin_pamparam_internal.flags & BLIN_TRAC) {
         fprintf(blin_pamparam_internal.w[0].file, "BLIN: +blin_dumb %08X %"BLIN_D"\n", mode, len);
